from setuptools import setup, find_packages

setup(
    name='edprompt',
    version='0.0.5',
    description='python shell prompt cli editor joke saver prompt bloody hell lmao 🤣🤣🤣',
    author='du7ec',
    author_email='dutec6834@gmail.com',
    url='https://github.com/FarAway6834/edprompt',
    packages=find_packages(exclude=[]),
    install_requires=['clro'],
    keywords=['python', 'shell', 'prompt', 'cli', 'editer', 'joke' 'saver', 'edprompt'],
    python_requires='>=3.6',
    package_data={},
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: 3.14',
    ],
)
